import React, { Ref, ReactNode, CSSProperties as CSSProperties$1, ReactElement } from 'react';
import { VariableSizeGrid, GridOnScrollProps } from 'react-window';
import { CSSProperties, StyleSheetManagerProps } from 'styled-components';

type TTitle = ReactNode | (({ dataIndex, column, isDraging }: {
    dataIndex: string;
    column: IVariableColumn;
    isDraging: boolean;
}) => ReactNode);
interface IVariableColumn<RecordType = any> {
    width: string | number;
    title?: TTitle;
    dataIndex: string;
    fixed?: boolean;
    sortOrder?: "ascend" | "descend" | false;
    sorter?: boolean;
    resizer?: boolean;
    reposition?: boolean;
    render?: ({ columnIndex, rowIndex, dataIndex, value, record, column, }: {
        columnIndex: number;
        rowIndex: number;
        dataIndex: string;
        value: any;
        record: RecordType;
        column: IVariableColumn;
    }) => ReactNode;
    [prop: string]: any;
}
type TPlaceholder$1<RecordType = any> = ReactNode | (({ columnIndex, rowIndex, dataIndex, record, column, value, }: {
    columnIndex: number;
    rowIndex: number;
    record: RecordType;
    column: IVariableColumn;
    dataIndex: string;
    value: any;
}) => ReactNode);
type TRowRender$1 = ({ columnIndex, data }: {
    columnIndex: number;
    data: TObject;
    width: number;
}) => ReactNode;
type TEmptyRender = (css: CSSProperties) => ReactNode;
type TObject = {
    [key: string]: any;
    children?: TObject[];
};
interface IRawItem$1 {
    [key: string]: any;
    children?: IRawItem$1[];
}
type TInitialScrollRowIndex = ((flatRawData: TObject[]) => number) | number;
type TInitialScrollColumnIndex<RecordType> = ((columns: IVariableColumn<RecordType>[]) => number) | number;
type TOnChange = ({ sorter, columnSize, columnPosition, action, }: {
    sorter?: {
        dataIndex: string;
        order: "ascend" | "descend" | undefined;
        column: IVariableColumn;
        columns: IVariableColumn[];
    };
    columnSize?: {
        dataIndex: string;
        width: number;
        column: IVariableColumn;
        columns: IVariableColumn[];
    };
    columnPosition?: {
        dataIndex: string;
        from: number;
        to: number;
        columns: IVariableColumn[];
    };
    action: "sort" | "resizeColumn" | "repositionColumn";
}) => void;
interface VariableTable<RecordType> {
    rawData: IRawItem$1[];
    columns: IVariableColumn<RecordType>[];
    rowHeight?: (index: number) => number;
    columnWidth: (index: number) => number;
    grid: VariableSizeGrid | null;
}
interface VariableTableLocale {
    noData?: string;
}
interface IProps$1<RecordType> {
    locale?: VariableTableLocale;
    ref?: Ref<VariableSizeGrid>;
    outerRef?: Ref<HTMLElement>;
    innerRef?: Ref<HTMLElement>;
    direction?: "ltr" | "rtl";
    rawData: IRawItem$1[];
    columnWidth?: (index: number) => number;
    rowHeight?: (index: number, data: IRawItem$1) => number;
    onScroll?: (props: GridOnScrollProps) => any;
    onChange?: TOnChange;
    columns: IVariableColumn<RecordType>[];
    height: number;
    width: number;
    header?: boolean | number;
    placeholder?: TPlaceholder$1;
    initialScrollRowIndex?: TInitialScrollRowIndex;
    initialScrollColumnIndex?: TInitialScrollColumnIndex<RecordType>;
    initialScrollLeft?: number;
    initialScrollTop?: number;
    itemKey: ({ columnIndex, data, rowIndex }: {
        columnIndex: number;
        data: any;
        rowIndex: number;
    }) => string;
    className?: string;
    style?: CSSProperties;
    innerClassName?: string;
    bodyClassName?: string;
    stickyBodyClassName?: string;
    headerClassName?: string;
    stickyHeaderClassName?: string;
    useIsScrolling?: boolean;
    overscanColumnCount?: number;
    overscanRowCount?: number;
    childrenRawName?: string;
    groupRowRender?: TRowRender$1;
    emptyRender?: TEmptyRender;
    styleSheetManagerProps?: StyleSheetManagerProps;
}

declare const _default$1: React.ForwardRefExoticComponent<Omit<IProps$1<unknown>, "ref"> & React.RefAttributes<VariableTable<unknown>>>;

type TRowRender = ({ rowIndex, columnIndex, data, style, }: {
    rowIndex: number;
    columnIndex: number;
    data: IRawItem;
    style: CSSProperties$1;
}) => ReactNode;
type TGroupRender = ({ data, style }: {
    data: IRawItem;
    style: CSSProperties$1;
}) => ReactElement;
type TCellRender = ({ rowIndex, columnIndex, data, style, }: {
    rowIndex: number;
    columnIndex: number;
    data: IRawItem;
    style: CSSProperties$1;
}) => ReactNode;
type TPlaceholder = ReactNode | (({ columnIndex, rowIndex, data }: {
    columnIndex: number;
    rowIndex: number;
    data: IRawItem;
}) => ReactNode);
interface IRawItem {
    [key: string]: any;
    children?: IRawItem[];
}
interface IProps<T> {
    ref?: Ref<VariableSizeGrid>;
    outerRef?: Ref<HTMLElement>;
    innerRef?: Ref<HTMLElement>;
    groupRowHeight?: ((index: number, raw: IRawItem) => number) | number;
    cellHeight: number;
    cellWidth: number;
    height: number;
    width: number;
    scrollbarSize: number;
    rawData: IRawItem[];
    itemKey: ({ columnIndex, data, rowIndex }: {
        columnIndex: number;
        data: any;
        rowIndex: number;
    }) => string;
    placeholder?: TPlaceholder;
    groupRowRender?: TRowRender;
    groupRender?: TGroupRender;
    cellRender?: TCellRender;
    className?: string;
    style?: CSSProperties$1;
    innerClassName?: string;
    useIsScrolling?: boolean;
    overscanRowCount?: number;
    childrenRawName?: string;
    isShowEmptyGroup?: boolean;
    initialScrollTop: number;
    onScroll?: (props: GridOnScrollProps) => any;
}

declare const _default: React.ForwardRefExoticComponent<Omit<IProps<unknown>, "ref"> & React.RefAttributes<VariableSizeGrid<any>>>;

export { _default as VariableMatrix, _default$1 as VariableTable };
